@@ -2,9 +2,6 @@
 A module for every constant of asymmetric.
 """
 
-# Logs
-LOG_FILE_NAME = "asymmetric.log"
-
 # HTTP related
 HTTP_METHODS = [
     "get",
@@ -16,3 +13,8 @@ HTTP_METHODS = [
     "patch",
     "trace",
 ]
+
+# Docs
+OPENAPI_SPEC_ROUTE = "/openapi.json"
+SWAGGER_DOCUMENTATION_ROUTE = "/docs"
+REDOC_DOCUMENTATION_ROUTE = "/redoc"
